summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--include/private/pthread_support.h2
-rw-r--r--pthread_start.c6
-rw-r--r--pthread_support.c12
3 files changed, 10 insertions, 10 deletions
diff --git a/include/private/pthread_support.h b/include/private/pthread_support.h
index e10f5aa1..ea1554c9 100644
--- a/include/private/pthread_support.h
+++ b/include/private/pthread_support.h
@@ -304,7 +304,7 @@ GC_INNER GC_thread GC_lookup_thread(thread_id_t);
#endif
#ifndef GC_WIN32_THREADS
- GC_INNER_PTHRSTART void * GC_CALLBACK GC_inner_start_routine(
+ GC_INNER_PTHRSTART void *GC_CALLBACK GC_pthread_start_inner(
struct GC_stack_base *sb, void *arg);
GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
void *(**pstart)(void *),
diff --git a/pthread_start.c b/pthread_start.c
index 62e3ac8f..0630fde5 100644
--- a/pthread_start.c
+++ b/pthread_start.c
@@ -17,7 +17,7 @@
/* We want to make sure that GC_thread_exit_proc() is unconditionally */
/* invoked, even if the client is not compiled with -fexceptions, but */
/* the GC is. The workaround is to put GC_inner_start_routine() in its */
/* own file (pthread_start.c), and undefine __EXCEPTIONS in the GCC */
/* case at the top of the file. FIXME: it's still unclear whether this */
/* will actually cause the exit handler to be invoked last when */
@@ -40,8 +40,8 @@
#include <sched.h>
-/* Invoked from GC_start_routine(). */
-GC_INNER_PTHRSTART void * GC_CALLBACK GC_inner_start_routine(
+/* Invoked from GC_pthread_start. */
+GC_INNER_PTHRSTART void *GC_CALLBACK GC_pthread_start_inner(
struct GC_stack_base *sb, void *arg)
{
void * (*start)(void *);
@@ -17,7 +17,7 @@
/* We want to make sure that GC_thread_exit_proc() is unconditionally */
/* invoked, even if the client is not compiled with -fexceptions, but */
-/* the GC is. The workaround is to put GC_inner_start_routine() in its */
+/* the GC is. The workaround is to put GC_pthread_start_inner() in its */
/* own file (pthread_start.c), and undefine __EXCEPTIONS in the GCC */
/* case at the top of the file. FIXME: it's still unclear whether this */
diff --git a/pthread_support.c b/pthread_support.c
index eb2cb658..fd14b1b0 100644
--- a/pthread_support.c
+++ b/pthread_support.c
@@ -2113,7 +2113,7 @@ struct start_info {
/* parent hasn't yet noticed. */
};
/* Called from GC_inner_start_routine(). Defined in this file to */
/* minimize the number of include files in pthread_start.c (because */
/* sem_t and sem_post() are not used that file directly). */
GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
@@ -2148,7 +2148,7 @@ GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
}
#if !defined(SN_TARGET_ORBIS) && !defined(SN_TARGET_PSP2)
- STATIC void * GC_start_routine(void * arg)
+ STATIC void * GC_pthread_start(void * arg)
{
# ifdef INCLUDE_LINUX_THREAD_DESCR
struct GC_stack_base sb;
@@ -2165,9 +2165,9 @@ GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
# ifdef REDIRECT_MALLOC
GC_enable();
# endif
- return GC_inner_start_routine(&sb, arg);
+ return GC_pthread_start_inner(&sb, arg);
# else
- return GC_call_with_stack_base(GC_inner_start_routine, arg);
+ return GC_call_with_stack_base(GC_pthread_start_inner, arg);
# endif
}
@@ -2242,8 +2242,8 @@ GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
GC_start_mark_threads();
# endif
set_need_to_lock();
- result = REAL_FUNC(pthread_create)(new_thread, attr, GC_start_routine,
- &si);
+ result = REAL_FUNC(pthread_create)(new_thread, attr,
+ GC_pthread_start, &si);
/* Wait until child has been added to the thread table. */
/* This also ensures that we hold onto the stack-allocated si until */
@@ -2113,7 +2113,7 @@ struct start_info {
/* parent hasn't yet noticed. */
};
-/* Called from GC_inner_start_routine(). Defined in this file to */
+/* Called from GC_pthread_start_inner(). Defined in this file to */
/* minimize the number of include files in pthread_start.c (because */
/* sem_t and sem_post() are not used that file directly). */